from abc import ABC, abstractmethod
from dataclasses import dataclass

from _qwak_proto.qwak.feature_store.sinks.sink_pb2 import (
    OfflineStreamingAttachmentPoint as ProtoOfflineStreamingAttachmentPoint,
    OnlineStreamingAttachmentPoint as ProtoOnlineStreamingAttachmentPoint,
    StreamingAttachmentPoint as ProtoStreamingAttachmentPoint,
)


class StreamingAttachmentPoint(ABC):
    @abstractmethod
    def _to_proto(self) -> ProtoStreamingAttachmentPoint:
        pass


@dataclass
class OfflineStreamingAttachmentPoint(StreamingAttachmentPoint):
    def _to_proto(self) -> ProtoStreamingAttachmentPoint:
        return ProtoStreamingAttachmentPoint(
            offline_streaming_attachment_point=ProtoOfflineStreamingAttachmentPoint()
        )


@dataclass
class OnlineStreamingAttachmentPoint(StreamingAttachmentPoint):
    def _to_proto(self) -> ProtoStreamingAttachmentPoint:
        return ProtoStreamingAttachmentPoint(
            online_streaming_attachment_point=ProtoOnlineStreamingAttachmentPoint()
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/account/v1/account_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.account.v1 import jfrog_tenant_details_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_jfrog__tenant__details__pb2
from _qwak_proto.qwak.administration.account.v1 import account_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_account__pb2
from _qwak_proto.qwak.administration.account.v1 import preferences_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_preferences__pb2
from _qwak_proto.qwak.administration.account.v1 import terms_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_terms__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4qwak/administration/account/v1/account_service.proto\x12\x1eqwak.administration.account.v1\x1a\x39qwak/administration/account/v1/jfrog_tenant_details.proto\x1a,qwak/administration/account/v1/account.proto\x1a\x30qwak/administration/account/v1/preferences.proto\x1a*qwak/administration/account/v1/terms.proto\"\xb4\x02\n\x14\x43reateAccountRequest\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\x12\x44\n\x0bpreferences\x18\x02 \x01(\x0b\x32/.qwak.administration.account.AccountPreferences\x12\x39\n\x04type\x18\x03 \x01(\x0e\x32+.qwak.administration.account.v1.AccountType\x12\x39\n\x04tier\x18\x04 \x01(\x0e\x32+.qwak.administration.account.v1.AccountTier\x12J\n\x11jfrog_tenant_spec\x18\x05 \x01(\x0b\x32/.qwak.administration.account.v1.JfrogTenantSpec\"Q\n\x15\x43reateAccountResponse\x12\x38\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\'.qwak.administration.account.v1.Account\"\'\n\x11GetAccountRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\"N\n\x12GetAccountResponse\x12\x38\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\'.qwak.administration.account.v1.Account\"X\n\x13ListAccountsRequest\x12\x41\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x31.qwak.administration.account.v1.ListAccountFilter\"Q\n\x14ListAccountsResponse\x12\x39\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\'.qwak.administration.account.v1.Account\"\xfd\x02\n\x14UpdateAccountRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x44\n\x0bpreferences\x18\x02 \x01(\x0b\x32/.qwak.administration.account.AccountPreferences\x12\x39\n\x04type\x18\x03 \x01(\x0e\x32+.qwak.administration.account.v1.AccountType\x12\x39\n\x04tier\x18\x04 \x01(\x0e\x32+.qwak.administration.account.v1.AccountTier\x12I\n\x0e\x61\x63\x63\x65pted_terms\x18\x05 \x01(\x0b\x32\x31.qwak.administration.account.AccountAcceptedTerms\x12J\n\x11jfrog_tenant_spec\x18\x06 \x01(\x0b\x32/.qwak.administration.account.v1.JfrogTenantSpec\"\x17\n\x15UpdateAccountResponse\"{\n\x1fUpdateAccountPreferencesRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x44\n\x0bpreferences\x18\x02 \x01(\x0b\x32/.qwak.administration.account.AccountPreferences\"\"\n UpdateAccountPreferencesResponse\"\x82\x01\n!UpdateAccountAcceptedTermsRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12I\n\x0e\x61\x63\x63\x65pted_terms\x18\x02 \x01(\x0b\x32\x31.qwak.administration.account.AccountAcceptedTerms\"$\n\"UpdateAccountAcceptedTermsResponse\"z\n\x15\x41\x64\x64\x41utoBindingRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12M\n\x14\x61uto_binding_account\x18\x02 \x03(\x0b\x32/.qwak.administration.account.v1.AutoBindingRule\"j\n\x16\x41\x64\x64\x41utoBindingResponse\x12P\n\x14\x61uto_binding_account\x18\x01 \x03(\x0b\x32\x32.qwak.administration.account.v1.AutoBindingAccount\"Q\n\x18RemoveAutoBindingRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12!\n\x19\x61uto_binding_id_to_remove\x18\x02 \x03(\t\"\x1b\n\x19RemoveAutoBindingResponse\"_\n\x16GetAccountBriefRequest\x12\x14\n\naccount_id\x18\x01 \x01(\tH\x00\x12\x19\n\x0fjfrog_tenant_id\x18\x02 \x01(\tH\x00\x42\x14\n\x12\x61\x63\x63ount_identifier\"^\n\x17GetAccountBriefResponse\x12\x43\n\raccount_brief\x18\x01 \x01(\x0b\x32,.qwak.administration.account.v1.AccountBrief2\xd3\t\n\x0e\x41\x63\x63ountService\x12|\n\rCreateAccount\x12\x34.qwak.administration.account.v1.CreateAccountRequest\x1a\x35.qwak.administration.account.v1.CreateAccountResponse\x12s\n\nGetAccount\x12\x31.qwak.administration.account.v1.GetAccountRequest\x1a\x32.qwak.administration.account.v1.GetAccountResponse\x12y\n\x0cListAccounts\x12\x33.qwak.administration.account.v1.ListAccountsRequest\x1a\x34.qwak.administration.account.v1.ListAccountsResponse\x12|\n\rUpdateAccount\x12\x34.qwak.administration.account.v1.UpdateAccountRequest\x1a\x35.qwak.administration.account.v1.UpdateAccountResponse\x12\x9d\x01\n\x18UpdateAccountPreferences\x12?.qwak.administration.account.v1.UpdateAccountPreferencesRequest\x1a@.qwak.administration.account.v1.UpdateAccountPreferencesResponse\x12\xa3\x01\n\x1aUpdateAccountAcceptedTerms\x12\x41.qwak.administration.account.v1.UpdateAccountAcceptedTermsRequest\x1a\x42.qwak.administration.account.v1.UpdateAccountAcceptedTermsResponse\x12\x7f\n\x0e\x41\x64\x64\x41utoBinding\x12\x35.qwak.administration.account.v1.AddAutoBindingRequest\x1a\x36.qwak.administration.account.v1.AddAutoBindingResponse\x12\x88\x01\n\x11RemoveAutoBinding\x12\x38.qwak.administration.account.v1.RemoveAutoBindingRequest\x1a\x39.qwak.administration.account.v1.RemoveAutoBindingResponse\x12\x82\x01\n\x0fGetAccountBrief\x12\x36.qwak.administration.account.v1.GetAccountBriefRequest\x1a\x37.qwak.administration.account.v1.GetAccountBriefResponseB\xb4\x01\n)com.qwak.ai.administration.api.account.v1P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.account.v1.account_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.account.v1P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0'
  _globals['_CREATEACCOUNTREQUEST']._serialized_start=288
  _globals['_CREATEACCOUNTREQUEST']._serialized_end=596
  _globals['_CREATEACCOUNTRESPONSE']._serialized_start=598
  _globals['_CREATEACCOUNTRESPONSE']._serialized_end=679
  _globals['_GETACCOUNTREQUEST']._serialized_start=681
  _globals['_GETACCOUNTREQUEST']._serialized_end=720
  _globals['_GETACCOUNTRESPONSE']._serialized_start=722
  _globals['_GETACCOUNTRESPONSE']._serialized_end=800
  _globals['_LISTACCOUNTSREQUEST']._serialized_start=802
  _globals['_LISTACCOUNTSREQUEST']._serialized_end=890
  _globals['_LISTACCOUNTSRESPONSE']._serialized_start=892
  _globals['_LISTACCOUNTSRESPONSE']._serialized_end=973
  _globals['_UPDATEACCOUNTREQUEST']._serialized_start=976
  _globals['_UPDATEACCOUNTREQUEST']._serialized_end=1357
  _globals['_UPDATEACCOUNTRESPONSE']._serialized_start=1359
  _globals['_UPDATEACCOUNTRESPONSE']._serialized_end=1382
  _globals['_UPDATEACCOUNTPREFERENCESREQUEST']._serialized_start=1384
  _globals['_UPDATEACCOUNTPREFERENCESREQUEST']._serialized_end=1507
  _globals['_UPDATEACCOUNTPREFERENCESRESPONSE']._serialized_start=1509
  _globals['_UPDATEACCOUNTPREFERENCESRESPONSE']._serialized_end=1543
  _globals['_UPDATEACCOUNTACCEPTEDTERMSREQUEST']._serialized_start=1546
  _globals['_UPDATEACCOUNTACCEPTEDTERMSREQUEST']._serialized_end=1676
  _globals['_UPDATEACCOUNTACCEPTEDTERMSRESPONSE']._serialized_start=1678
  _globals['_UPDATEACCOUNTACCEPTEDTERMSRESPONSE']._serialized_end=1714
  _globals['_ADDAUTOBINDINGREQUEST']._serialized_start=1716
  _globals['_ADDAUTOBINDINGREQUEST']._serialized_end=1838
  _globals['_ADDAUTOBINDINGRESPONSE']._serialized_start=1840
  _globals['_ADDAUTOBINDINGRESPONSE']._serialized_end=1946
  _globals['_REMOVEAUTOBINDINGREQUEST']._serialized_start=1948
  _globals['_REMOVEAUTOBINDINGREQUEST']._serialized_end=2029
  _globals['_REMOVEAUTOBINDINGRESPONSE']._serialized_start=2031
  _globals['_REMOVEAUTOBINDINGRESPONSE']._serialized_end=2058
  _globals['_GETACCOUNTBRIEFREQUEST']._serialized_start=2060
  _globals['_GETACCOUNTBRIEFREQUEST']._serialized_end=2155
  _globals['_GETACCOUNTBRIEFRESPONSE']._serialized_start=2157
  _globals['_GETACCOUNTBRIEFRESPONSE']._serialized_end=2251
  _globals['_ACCOUNTSERVICE']._serialized_start=2254
  _globals['_ACCOUNTSERVICE']._serialized_end=3489
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/builds/build_values.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eqwak/builds/build_values.proto\x12\x15qwak.build.management\x1a/qwak/user_application/common/v0/resources.proto\"\xc3\x03\n\x10ModelBuildValues\x12\x34\n\nbuild_info\x18\x01 \x01(\x0b\x32 .qwak.build.management.BuildInfo\x12<\n\x0emodel_metadata\x18\x02 \x01(\x0b\x32$.qwak.build.management.ModelMetadata\x12\x45\n\x13model_code_location\x18\x03 \x01(\x0b\x32(.qwak.build.management.ModelCodeLocation\x12G\n\x14\x62uild_execution_spec\x18\x04 \x01(\x0b\x32).qwak.build.management.BuildExecutionSpec\x12\x30\n\x08sdk_spec\x18\x05 \x01(\x0b\x32\x1e.qwak.build.management.SdkSpec\x12G\n\x14jfrog_ecosystem_spec\x18\x06 \x01(\x0b\x32).qwak.build.management.JfrogEcosystemSpec\x12\x30\n\x08job_spec\x18\x07 \x01(\x0b\x32\x1e.qwak.build.management.JobSpec\"\xa3\x01\n\tBuildInfo\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x13\n\x0b\x62ranch_name\x18\x02 \x01(\t\x12\x12\n\nbuild_tags\x18\x03 \x03(\t\x12\x14\n\x0c\x62uild_config\x18\x04 \x01(\t\x12\x45\n\x13\x62uild_properties_v1\x18\x05 \x01(\x0b\x32(.qwak.build.management.BuildPropertiesV1\"]\n\x11\x42uildPropertiesV1\x12\x18\n\x10\x62uild_config_url\x18\x01 \x01(\t\x12\x15\n\rsdk_wheel_url\x18\x02 \x01(\t\x12\x17\n\x0fsdk_version_url\x18\x03 \x01(\t\"\x8e\x01\n\rModelMetadata\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x12\n\naccount_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x46\n\x13\x61rtifactory_details\x18\x04 \x01(\x0b\x32).qwak.build.management.ArtifactoryDetails\")\n\x12\x41rtifactoryDetails\x12\x13\n\x0bproject_key\x18\x01 \x01(\t\"\xa0\x01\n\x11ModelCodeLocation\x12\x1c\n\x14main_model_directory\x18\x01 \x01(\t\x12\x34\n\tlocal_uri\x18\x02 \x01(\x0b\x32\x1f.qwak.build.management.LocalUriH\x00\x12\x30\n\x07git_uri\x18\x03 \x01(\x0b\x32\x1d.qwak.build.management.GitUriH\x00\x42\x05\n\x03uri\"\x18\n\x08LocalUri\x12\x0c\n\x04path\x18\x01 \x01(\t\"M\n\x06GitUri\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x36\n\x0bgit_details\x18\x02 \x01(\x0b\x32!.qwak.build.management.GitDetails\"|\n\nGitDetails\x12\x0e\n\x06\x62ranch\x18\x01 \x01(\t\x12\x11\n\tcommit_id\x18\x02 \x01(\t\x12\x15\n\x0b\x63redentials\x18\x03 \x01(\tH\x00\x12!\n\x17\x63redentials_secret_name\x18\x04 \x01(\tH\x00\x42\x11\n\x0fgit_credentials\"\xd0\x02\n\x12\x42uildExecutionSpec\x12\x1f\n\x17\x62uild_image_destination\x18\x01 \x01(\t\x12\"\n\x1ashould_build_without_cache\x18\x02 \x01(\x08\x12G\n\x14logs_verbosity_level\x18\x03 \x01(\x0e\x32).qwak.build.management.LogsVerbosityLevel\x12\x12\n\nbase_image\x18\x04 \x01(\t\x12\x1b\n\x13\x63ustom_iam_role_arn\x18\x05 \x01(\t\x12\x10\n\x08\x65nv_vars\x18\x06 \x03(\t\x12\'\n\x1fremote_builder_auth_secret_name\x18\x07 \x01(\t\x12@\n\x10\x63ontainer_engine\x18\x08 \x01(\x0b\x32&.qwak.build.management.ContainerEngine\"a\n\x07SdkSpec\x12\x13\n\x0bsdk_version\x18\x01 \x01(\t\x12\x1b\n\x13sdk_extra_index_url\x18\x02 \x01(\t\x12$\n\x1csdk_runtime_version_override\x18\x03 \x01(\t\"k\n\x12JfrogEcosystemSpec\x12\x0f\n\x07\x62\x61seUrl\x18\x01 \x01(\t\x12\x1d\n\x15\x61\x63\x63\x65ssTokenSecretName\x18\x02 \x01(\t\x12%\n\x1d\x61rtifactorySettingsSecretName\x18\x03 \x01(\t\"\xb5\x04\n\x07JobSpec\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\"\n\x1aprovision_instance_timeout\x18\x02 \x01(\x05\x12>\n\x0fpurchase_option\x18\x03 \x01(\x0e\x32%.qwak.build.management.PurchaseOption\x12$\n\x1cis_node_optimization_enabled\x18\x04 \x01(\x08\x12\"\n\x1ashould_use_build_isolation\x18\x05 \x01(\x08\x12#\n\x1bis_multi_tenant_environment\x18\x06 \x01(\x08\x12\x1a\n\x12is_self_hosted_jpd\x18\n \x01(\x08\x12 \n\x18\x62uild_executor_image_url\x18\x07 \x01(\t\x12<\n\x0e\x63loud_provider\x18\x08 \x01(\x0e\x32$.qwak.build.management.CloudProvider\x12\x30\n\x08job_size\x18\t \x01(\x0b\x32\x1e.qwak.build.management.JobSize\x12Y\n\x17\x62uild_executor_env_vars\x18\x0b \x03(\x0b\x32\x38.qwak.build.management.JobSpec.BuildExecutorEnvVarsEntry\x1a;\n\x19\x42uildExecutorEnvVarsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x02\n\x07JobSize\x12\x0f\n\x03\x63pu\x18\x01 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rmemory_amount\x18\x02 \x01(\x05\x42\x02\x18\x01\x12;\n\x0cmemory_units\x18\x03 \x01(\x0e\x32!.qwak.build.management.MemoryUnitB\x02\x18\x01\x12H\n\rgpu_resources\x18\x04 \x01(\x0b\x32-.qwak.user_application.common.v0.GpuResourcesB\x02\x18\x01\x12`\n\x1c\x63lient_pod_compute_resources\x18\x05 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\"\x9d\x01\n\x0f\x43ontainerEngine\x12>\n\x06\x64ocker\x18\x01 \x01(\x0b\x32,.qwak.build.management.DockerContainerEngineH\x00\x12\x42\n\x06podman\x18\x02 \x01(\x0b\x32,.qwak.build.management.PodmanContainerEngineB\x02\x18\x01H\x00\x42\x06\n\x04type\"\x17\n\x15\x44ockerContainerEngine\"\x17\n\x15PodmanContainerEngine*e\n\x0ePurchaseOption\x12\x1b\n\x17INVALID_PURCHASE_OPTION\x10\x00\x12\x18\n\x14SPOT_PURCHASE_OPTION\x10\x01\x12\x1c\n\x18ONDEMAND_PURCHASE_OPTION\x10\x02*H\n\rCloudProvider\x12\x1a\n\x16INVALID_CLOUD_PROVIDER\x10\x00\x12\x07\n\x03\x41WS\x10\x01\x12\x07\n\x03GCP\x10\x02\x12\t\n\x05\x41ZURE\x10\x03*7\n\nMemoryUnit\x12\x17\n\x13INVALID_MEMORY_UNIT\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02*S\n\x12LogsVerbosityLevel\x12\x1a\n\x16INVALID_LOGS_VERBOSITY\x10\x00\x12\t\n\x05\x44\x45\x42UG\x10\n\x12\x08\n\x04INFO\x10\x14\x12\x0c\n\x08\x43RITICAL\x10\x32\x42\x36\n com.qwak.ai.management.build.apiP\x01Z\x10qwak/build;buildb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.builds.build_values_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n com.qwak.ai.management.build.apiP\001Z\020qwak/build;build'
  _JOBSPEC_BUILDEXECUTORENVVARSENTRY._options = None
  _JOBSPEC_BUILDEXECUTORENVVARSENTRY._serialized_options = b'8\001'
  _JOBSIZE.fields_by_name['cpu']._options = None
  _JOBSIZE.fields_by_name['cpu']._serialized_options = b'\030\001'
  _JOBSIZE.fields_by_name['memory_amount']._options = None
  _JOBSIZE.fields_by_name['memory_amount']._serialized_options = b'\030\001'
  _JOBSIZE.fields_by_name['memory_units']._options = None
  _JOBSIZE.fields_by_name['memory_units']._serialized_options = b'\030\001'
  _JOBSIZE.fields_by_name['gpu_resources']._options = None
  _JOBSIZE.fields_by_name['gpu_resources']._serialized_options = b'\030\001'
  _CONTAINERENGINE.fields_by_name['podman']._options = None
  _CONTAINERENGINE.fields_by_name['podman']._serialized_options = b'\030\001'
  _globals['_PURCHASEOPTION']._serialized_start=3017
  _globals['_PURCHASEOPTION']._serialized_end=3118
  _globals['_CLOUDPROVIDER']._serialized_start=3120
  _globals['_CLOUDPROVIDER']._serialized_end=3192
  _globals['_MEMORYUNIT']._serialized_start=3194
  _globals['_MEMORYUNIT']._serialized_end=3249
  _globals['_LOGSVERBOSITYLEVEL']._serialized_start=3251
  _globals['_LOGSVERBOSITYLEVEL']._serialized_end=3334
  _globals['_MODELBUILDVALUES']._serialized_start=107
  _globals['_MODELBUILDVALUES']._serialized_end=558
  _globals['_BUILDINFO']._serialized_start=561
  _globals['_BUILDINFO']._serialized_end=724
  _globals['_BUILDPROPERTIESV1']._serialized_start=726
  _globals['_BUILDPROPERTIESV1']._serialized_end=819
  _globals['_MODELMETADATA']._serialized_start=822
  _globals['_MODELMETADATA']._serialized_end=964
  _globals['_ARTIFACTORYDETAILS']._serialized_start=966
  _globals['_ARTIFACTORYDETAILS']._serialized_end=1007
  _globals['_MODELCODELOCATION']._serialized_start=1010
  _globals['_MODELCODELOCATION']._serialized_end=1170
  _globals['_LOCALURI']._serialized_start=1172
  _globals['_LOCALURI']._serialized_end=1196
  _globals['_GITURI']._serialized_start=1198
  _globals['_GITURI']._serialized_end=1275
  _globals['_GITDETAILS']._serialized_start=1277
  _globals['_GITDETAILS']._serialized_end=1401
  _globals['_BUILDEXECUTIONSPEC']._serialized_start=1404
  _globals['_BUILDEXECUTIONSPEC']._serialized_end=1740
  _globals['_SDKSPEC']._serialized_start=1742
  _globals['_SDKSPEC']._serialized_end=1839
  _globals['_JFROGECOSYSTEMSPEC']._serialized_start=1841
  _globals['_JFROGECOSYSTEMSPEC']._serialized_end=1948
  _globals['_JOBSPEC']._serialized_start=1951
  _globals['_JOBSPEC']._serialized_end=2516
  _globals['_JOBSPEC_BUILDEXECUTORENVVARSENTRY']._serialized_start=2457
  _globals['_JOBSPEC_BUILDEXECUTORENVVARSENTRY']._serialized_end=2516
  _globals['_JOBSIZE']._serialized_start=2519
  _globals['_JOBSIZE']._serialized_end=2805
  _globals['_CONTAINERENGINE']._serialized_start=2808
  _globals['_CONTAINERENGINE']._serialized_end=2965
  _globals['_DOCKERCONTAINERENGINE']._serialized_start=2967
  _globals['_DOCKERCONTAINERENGINE']._serialized_end=2990
  _globals['_PODMANCONTAINERENGINE']._serialized_start=2992
  _globals['_PODMANCONTAINERENGINE']._serialized_end=3015
# @@protoc_insertion_point(module_scope)



from os import getenv
from pathlib import Path

from _qwak_proto.qwak.batch_job.v1.batch_job_resources_pb2 import GpuType


class QwakConstants:
    """
    Qwak Configuration settings
    """

    QWAK_HOME = (
        getenv("QWAK_HOME")
        if getenv("QWAK_HOME") is not None
        else f"{str(Path.home())}"
    )

    QWAK_CONFIG_FOLDER: str = f"{QWAK_HOME}/.qwak"

    QWAK_LOGGER_FOLDER: str = f"{QWAK_CONFIG_FOLDER}/logs"

    QWAK_CONFIG_FILE: str = f"{QWAK_CONFIG_FOLDER}/config"

    QWAK_AUTHORIZATION_FILE: str = f"{QWAK_CONFIG_FOLDER}/auth"

    QWAK_DEFAULT_SECTION: str = "default"

    AUTH0_JWKS_URI = "https://dev-qwak.us.auth0.com/.well-known/jwks.json"

    AUTH0_ALGORITHMS = ["RS256"]

    GPU_TYPES = list(set(GpuType.DESCRIPTOR.values_by_name) - {"INVALID_GPU"})

    TOKEN_AUDIENCE: str = "https://auth-token.qwak.ai/"  # nosec B105

    QWAK_APP_URL: str = "https://app.qwak.ai"

    CONTROL_PLANE_GRPC_ADDRESS_ENVAR_NAME: str = "CONTROL_PLANE_GRPC_ADDRESS"



import logging
import re
import time
from abc import ABC, abstractmethod
from random import randint
from typing import Callable, Optional, Tuple
from urllib.parse import urlparse, ParseResult

import grpc

from qwak.exceptions import QwakException, QwakGrpcAddressException
from .grpc_auth import Auth0Client

logger = logging.getLogger()
HOSTNAME_REGEX: str = r"^(?!-)(?:[A-Za-z0-9-]{1,63}\.)*[A-Za-z0-9-]{1,63}(?<!-)$"


def create_grpc_channel(
    url: str,
    enable_ssl: bool = True,
    enable_auth: bool = True,
    auth_metadata_plugin: grpc.AuthMetadataPlugin = None,
    timeout: int = 100,
    options=None,
    backoff_options=None,
    max_attempts=4,
    status_for_retry=(grpc.StatusCode.UNAVAILABLE,),
    attempt=0,
) -> grpc.Channel:
    """
    Create a gRPC channel
    Args:
        url: gRPC URL to connect to
        enable_ssl: Enable TLS/SSL, optionally provide a server side certificate
        enable_auth: Enable user auth
        auth_metadata_plugin: Metadata plugin to use to sign requests, only used
            with "enable auth" when SSL/TLS is enabled
        timeout: Connection timeout to server
        options:  An optional list of key-value pairs (channel_arguments in gRPC Core runtime) to configure the channel.
        backoff_options: dictionary - init_backoff_ms: default 50, max_backoff_ms: default 500, multiplier: default 2
        max_attempts: max number of retry attempts
        attempt: current retry attempts
        status_for_retry: grpc statuses to retry upon
    Returns: Returns a grpc.Channel
    """
    if backoff_options is None:
        backoff_options = {}

    if not url:
        raise QwakException("Unable to create gRPC channel. URL has not been defined.")

    if enable_ssl or url.endswith(":443"):
        credentials = grpc.ssl_channel_credentials()
        if enable_auth:
            if auth_metadata_plugin is None:
                auth_metadata_plugin = Auth0Client()
            credentials = grpc.composite_channel_credentials(
                credentials, grpc.metadata_call_credentials(auth_metadata_plugin)
            )

        channel = grpc.secure_channel(url, credentials=credentials, options=options)
    else:
        channel = grpc.insecure_channel(url, options=options)
    try:
        interceptors = (
            RetryOnRpcErrorClientInterceptor(
                max_attempts=max_attempts,
                sleeping_policy=ExponentialBackoff(**backoff_options),
                status_for_retry=status_for_retry,
            ),
        )

        intercept_channel = grpc.intercept_channel(channel, *interceptors)
        try:
            grpc.channel_ready_future(intercept_channel).result(timeout=timeout)
        except (grpc.FutureTimeoutError, grpc.RpcError, Exception) as e:
            logger.debug(
                f"Received error: {repr(e)} attempt #{attempt + 1} of {max_attempts}"
            )
            if attempt < max_attempts:
                return create_grpc_channel(
                    url,
                    enable_ssl,
                    enable_auth,
                    auth_metadata_plugin,
                    timeout,
                    options,
                    backoff_options,
                    max_attempts,
                    status_for_retry,
                    attempt + 1,
                )
            else:
                raise e

        return intercept_channel
    except grpc.FutureTimeoutError as e:
        raise QwakException(
            f"Connection timed out while attempting to connect to {url}, with: {repr(e)}"
        ) from e


def create_grpc_channel_or_none(
    url: str,
    enable_ssl: bool = True,
    enable_auth: bool = True,
    auth_metadata_plugin: grpc.AuthMetadataPlugin = None,
    timeout: int = 30,
    options=None,
    backoff_options=None,
    max_attempts=2,
    status_for_retry=(grpc.StatusCode.UNAVAILABLE,),
    attempt=0,
) -> Callable[[Optional[str], Optional[bool]], Optional[grpc.Channel]]:
    if backoff_options is None:
        backoff_options = {}

    def deferred_channel(
        url_overwrite: Optional[str] = None, ssl_overwrite: Optional[bool] = None
    ):
        try:
            return create_grpc_channel(
                url_overwrite if url_overwrite else url,
                ssl_overwrite if ssl_overwrite else enable_ssl,
                enable_auth,
                auth_metadata_plugin,
                timeout,
                options,
                backoff_options,
                max_attempts,
                status_for_retry,
                attempt,
            )
        except Exception as e:
            logger.debug(f"create_grpc_channel error: {repr(e)}")
            return None

    return deferred_channel


def validate_grpc_address(
    grpc_address: str,
    is_port_specification_allowed: bool = False,
    is_url_scheme_allowed: bool = False,
):
    """
    Validate gRPC address format
    Args:
        grpc_address (str): gRPC address to validate
        is_port_specification_allowed (bool): Whether to allow port specification in the address
        is_url_scheme_allowed (bool): Whether to allow URL scheme in the address
    Raises:
        QwakGrpcAddressException: If the gRPC address is invalid
    """
    parsed_grpc_address: ParseResult = parse_address(grpc_address)
    hostname: str = get_hostname_from_address(parsed_grpc_address)
    validate_paths_are_not_included_in_address(parsed_grpc_address)

    if not is_url_scheme_allowed:
        __validate_url_scheme_not_included_in_address(parsed_grpc_address)

    if not is_port_specification_allowed:
        __validate_port_not_included_in_address(parsed_grpc_address)

    if not is_valid_hostname(hostname):
        raise QwakGrpcAddressException(
            "gRPC address must be a simple hostname or fully qualified domain name.",
            parsed_grpc_address,
        )


def validate_paths_are_not_included_in_address(
    parsed_grpc_address: ParseResult,
) -> None:
    has_invalid_path: bool = (
        parsed_grpc_address.path not in {"", "/"}
        or parsed_grpc_address.query
        or parsed_grpc_address.fragment
    )

    if has_invalid_path:
        raise QwakGrpcAddressException(
            "gRPC address must not contain paths, queries, or fragments.",
            parsed_grpc_address,
        )


def get_hostname_from_address(parsed_grpc_address: ParseResult) -> str:
    hostname: Optional[str] = parsed_grpc_address.hostname
    if not hostname:
        raise QwakGrpcAddressException(
            "gRPC address must contain a valid hostname.", parsed_grpc_address
        )

    return hostname


def __validate_url_scheme_not_included_in_address(
    parsed_grpc_address: ParseResult,
) -> None:
    if parsed_grpc_address.scheme:
        raise QwakGrpcAddressException(
            "URL scheme is not allowed in the gRPC address.", parsed_grpc_address
        )


def __validate_port_not_included_in_address(parsed_grpc_address: ParseResult):
    try:
        port: Optional[int] = parsed_grpc_address.port
    except ValueError as exc:
        raise QwakGrpcAddressException(
            "Invalid port specification in the gRPC address.", parsed_grpc_address
        ) from exc

    if port:
        raise QwakGrpcAddressException(
            "Port specification is not allowed in the gRPC address.",
            parsed_grpc_address,
        )


def parse_address(grpc_address: str) -> ParseResult:
    if not grpc_address or not grpc_address.strip():
        raise QwakGrpcAddressException(
            "gRPC address must not be empty or whitespace.", grpc_address
        )

    trimmed_address: str = grpc_address.strip()
    parsed_address: ParseResult = urlparse(
        trimmed_address if "://" in trimmed_address else f"//{trimmed_address}"
    )

    return parsed_address


def is_valid_hostname(hostname: str) -> bool:
    """
    Validate that the supplied hostname conforms to RFC-style label rules:
    anchored pattern enforces full-string validation, negative lookahead/lookbehind block
    leading or trailing hyphens per label, and each dot-separated label must be 1-63
    alphanumeric/hyphen characters.

    Args:
        hostname (str): The hostname to validate.
    Returns:
        bool: True if the hostname is valid, False otherwise.
    """
    hostname_pattern: re.Pattern = re.compile(HOSTNAME_REGEX)
    return bool(hostname_pattern.fullmatch(hostname))


class SleepingPolicy(ABC):
    @abstractmethod
    def sleep(self, try_i: int):
        """
        How long to sleep in milliseconds.
        :param try_i: the number of retry (starting from zero)
        """
        if try_i < 0:
            raise ValueError("Number of retries must be non-negative.")


class ExponentialBackoff(SleepingPolicy):
    def __init__(
        self,
        *,
        init_backoff_ms: int = 50,
        max_backoff_ms: int = 5000,
        multiplier: int = 2,
    ):
        self.init_backoff = init_backoff_ms
        self.max_backoff = max_backoff_ms
        self.multiplier = multiplier

    def sleep(self, try_i: int):
        sleep_time = min(self.init_backoff * self.multiplier**try_i, self.max_backoff)
        sleep_ms = sleep_time + randint(0, self.init_backoff)  # nosec B311
        logger.debug("ExponentialBackoff - Sleeping between retries")
        time.sleep(sleep_ms / 1000)


class RetryOnRpcErrorClientInterceptor(grpc.UnaryUnaryClientInterceptor):
    def __init__(
        self,
        *,
        max_attempts: int,
        sleeping_policy: SleepingPolicy,
        status_for_retry: Optional[Tuple[grpc.StatusCode]] = None,
    ):
        self.max_attempts = max_attempts
        self.sleeping_policy = sleeping_policy
        self.status_for_retry = status_for_retry

    def _intercept_call(self, continuation, client_call_details, request_or_iterator):
        for try_i in range(self.max_attempts):
            response = continuation(client_call_details, request_or_iterator)

            if isinstance(response, grpc.RpcError):
                # Return if it was last attempt
                if try_i == (self.max_attempts - 1):
                    return response

                # If status code is not in retryable status codes
                if (
                    self.status_for_retry
                    and response.code() not in self.status_for_retry
                ):
                    return response
                logger.debug(
                    f"Retry GRPC call attempt #{try_i} after status {response.code()}"
                )
                logger.debug(f"Client call details: {client_call_details}")
                self.sleeping_policy.sleep(try_i)
            else:
                return response

    def intercept_unary_unary(self, continuation, client_call_details, request):
        return self._intercept_call(continuation, client_call_details, request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/workspace/workspace_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.workspace import workspace_pb2 as qwak_dot_workspace_dot_workspace__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&qwak/workspace/workspace_service.proto\x12\x19qwak.workspace.management\x1a\x1eqwak/workspace/workspace.proto\"Z\n\x16\x43reateWorkspaceRequest\x12@\n\x0eworkspace_spec\x18\x01 \x01(\x0b\x32(.qwak.workspace.management.WorkspaceSpec\"/\n\x17\x43reateWorkspaceResponse\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"p\n\x16UpdateWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12@\n\x0eworkspace_spec\x18\x02 \x01(\x0b\x32(.qwak.workspace.management.WorkspaceSpec\".\n\x16\x44\x65ployWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"\x19\n\x17\x44\x65ployWorkspaceResponse\"0\n\x18UndeployWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"\x1b\n\x19UndeployWorkspaceResponse\"\x19\n\x17UpdateWorkspaceResponse\"\x17\n\x15ListWorkspacesRequest\"R\n\x16ListWorkspacesResponse\x12\x38\n\nworkspaces\x18\x01 \x03(\x0b\x32$.qwak.workspace.management.Workspace\"/\n\x17GetWorkspaceByIdRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"S\n\x18GetWorkspaceByIdResponse\x12\x37\n\tworkspace\x18\x01 \x01(\x0b\x32$.qwak.workspace.management.Workspace\".\n\x16\x44\x65leteWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\"\x19\n\x17\x44\x65leteWorkspaceResponse\"\x9a\x01\n$UpdateWorkspaceStatusFromEdgeRequest\x12r\n)update_workspace_status_from_edge_details\x18\x01 \x01(\x0b\x32?.qwak.workspace.management.UpdateWorkspaceStatusFromEdgeDetails\"\'\n%UpdateWorkspaceStatusFromEdgeResponse\"A\n\x1bRegisterWorkspaceTagRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x0c\n\x04tags\x18\x02 \x03(\t\"\x1e\n\x1cRegisterWorkspaceTagResponse\"\x1c\n\x1aListWorkspaceImagesRequest\"b\n\x1bListWorkspaceImagesResponse\x12\x43\n\x10workspace_images\x18\x01 \x03(\x0b\x32).qwak.workspace.management.WorkspaceImage\"\x18\n\x16\x43ountWorkspacesRequest\"(\n\x17\x43ountWorkspacesResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"\"\n GetDefaultWorkspaceValuesRequest\"z\n!GetDefaultWorkspaceValuesResponse\x12U\n\x19\x64\x65\x66\x61ult_workspace_details\x18\x01 \x01(\x0b\x32\x32.qwak.workspace.management.DefaultWorkspaceDetails\"B\n\x18MarkBuildAsCopiedRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\"\x1b\n\x19MarkBuildAsCopiedResponse\":\n\x10\x43opyBuildRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\"\x13\n\x11\x43opyBuildResponse2\xaa\x0e\n\x1aWorkspaceManagementService\x12x\n\x0f\x43reateWorkspace\x12\x31.qwak.workspace.management.CreateWorkspaceRequest\x1a\x32.qwak.workspace.management.CreateWorkspaceResponse\x12x\n\x0fUpdateWorkspace\x12\x31.qwak.workspace.management.UpdateWorkspaceRequest\x1a\x32.qwak.workspace.management.UpdateWorkspaceResponse\x12x\n\x0f\x44\x65ployWorkspace\x12\x31.qwak.workspace.management.DeployWorkspaceRequest\x1a\x32.qwak.workspace.management.DeployWorkspaceResponse\x12~\n\x11UndeployWorkspace\x12\x33.qwak.workspace.management.UndeployWorkspaceRequest\x1a\x34.qwak.workspace.management.UndeployWorkspaceResponse\x12u\n\x0eListWorkspaces\x12\x30.qwak.workspace.management.ListWorkspacesRequest\x1a\x31.qwak.workspace.management.ListWorkspacesResponse\x12{\n\x10GetWorkspaceById\x12\x32.qwak.workspace.management.GetWorkspaceByIdRequest\x1a\x33.qwak.workspace.management.GetWorkspaceByIdResponse\x12x\n\x0f\x44\x65leteWorkspace\x12\x31.qwak.workspace.management.DeleteWorkspaceRequest\x1a\x32.qwak.workspace.management.DeleteWorkspaceResponse\x12\xa2\x01\n\x1dUpdateWorkspaceStatusFromEdge\x12?.qwak.workspace.management.UpdateWorkspaceStatusFromEdgeRequest\x1a@.qwak.workspace.management.UpdateWorkspaceStatusFromEdgeResponse\x12\x84\x01\n\x13ListWorkspaceImages\x12\x35.qwak.workspace.management.ListWorkspaceImagesRequest\x1a\x36.qwak.workspace.management.ListWorkspaceImagesResponse\x12\x88\x01\n\x15RegisterWorkspaceTags\x12\x36.qwak.workspace.management.RegisterWorkspaceTagRequest\x1a\x37.qwak.workspace.management.RegisterWorkspaceTagResponse\x12x\n\x0f\x43ountWorkspaces\x12\x31.qwak.workspace.management.CountWorkspacesRequest\x1a\x32.qwak.workspace.management.CountWorkspacesResponse\x12\x96\x01\n\x19GetDefaultWorkspaceValues\x12;.qwak.workspace.management.GetDefaultWorkspaceValuesRequest\x1a<.qwak.workspace.management.GetDefaultWorkspaceValuesResponse\x12~\n\x11MarkBuildAsCopied\x12\x33.qwak.workspace.management.MarkBuildAsCopiedRequest\x1a\x34.qwak.workspace.management.MarkBuildAsCopiedResponse\x12\x66\n\tCopyBuild\x12+.qwak.workspace.management.CopyBuildRequest\x1a,.qwak.workspace.management.CopyBuildResponseBB\n$com.qwak.ai.management.workspace.apiP\x01Z\x18qwak/workspace;workspaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.workspace.workspace_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.qwak.ai.management.workspace.apiP\001Z\030qwak/workspace;workspace'
  _globals['_CREATEWORKSPACEREQUEST']._serialized_start=101
  _globals['_CREATEWORKSPACEREQUEST']._serialized_end=191
  _globals['_CREATEWORKSPACERESPONSE']._serialized_start=193
  _globals['_CREATEWORKSPACERESPONSE']._serialized_end=240
  _globals['_UPDATEWORKSPACEREQUEST']._serialized_start=242
  _globals['_UPDATEWORKSPACEREQUEST']._serialized_end=354
  _globals['_DEPLOYWORKSPACEREQUEST']._serialized_start=356
  _globals['_DEPLOYWORKSPACEREQUEST']._serialized_end=402
  _globals['_DEPLOYWORKSPACERESPONSE']._serialized_start=404
  _globals['_DEPLOYWORKSPACERESPONSE']._serialized_end=429
  _globals['_UNDEPLOYWORKSPACEREQUEST']._serialized_start=431
  _globals['_UNDEPLOYWORKSPACEREQUEST']._serialized_end=479
  _globals['_UNDEPLOYWORKSPACERESPONSE']._serialized_start=481
  _globals['_UNDEPLOYWORKSPACERESPONSE']._serialized_end=508
  _globals['_UPDATEWORKSPACERESPONSE']._serialized_start=510
  _globals['_UPDATEWORKSPACERESPONSE']._serialized_end=535
  _globals['_LISTWORKSPACESREQUEST']._serialized_start=537
  _globals['_LISTWORKSPACESREQUEST']._serialized_end=560
  _globals['_LISTWORKSPACESRESPONSE']._serialized_start=562
  _globals['_LISTWORKSPACESRESPONSE']._serialized_end=644
  _globals['_GETWORKSPACEBYIDREQUEST']._serialized_start=646
  _globals['_GETWORKSPACEBYIDREQUEST']._serialized_end=693
  _globals['_GETWORKSPACEBYIDRESPONSE']._serialized_start=695
  _globals['_GETWORKSPACEBYIDRESPONSE']._serialized_end=778
  _globals['_DELETEWORKSPACEREQUEST']._serialized_start=780
  _globals['_DELETEWORKSPACEREQUEST']._serialized_end=826
  _globals['_DELETEWORKSPACERESPONSE']._serialized_start=828
  _globals['_DELETEWORKSPACERESPONSE']._serialized_end=853
  _globals['_UPDATEWORKSPACESTATUSFROMEDGEREQUEST']._serialized_start=856
  _globals['_UPDATEWORKSPACESTATUSFROMEDGEREQUEST']._serialized_end=1010
  _globals['_UPDATEWORKSPACESTATUSFROMEDGERESPONSE']._serialized_start=1012
  _globals['_UPDATEWORKSPACESTATUSFROMEDGERESPONSE']._serialized_end=1051
  _globals['_REGISTERWORKSPACETAGREQUEST']._serialized_start=1053
  _globals['_REGISTERWORKSPACETAGREQUEST']._serialized_end=1118
  _globals['_REGISTERWORKSPACETAGRESPONSE']._serialized_start=1120
  _globals['_REGISTERWORKSPACETAGRESPONSE']._serialized_end=1150
  _globals['_LISTWORKSPACEIMAGESREQUEST']._serialized_start=1152
  _globals['_LISTWORKSPACEIMAGESREQUEST']._serialized_end=1180
  _globals['_LISTWORKSPACEIMAGESRESPONSE']._serialized_start=1182
  _globals['_LISTWORKSPACEIMAGESRESPONSE']._serialized_end=1280
  _globals['_COUNTWORKSPACESREQUEST']._serialized_start=1282
  _globals['_COUNTWORKSPACESREQUEST']._serialized_end=1306
  _globals['_COUNTWORKSPACESRESPONSE']._serialized_start=1308
  _globals['_COUNTWORKSPACESRESPONSE']._serialized_end=1348
  _globals['_GETDEFAULTWORKSPACEVALUESREQUEST']._serialized_start=1350
  _globals['_GETDEFAULTWORKSPACEVALUESREQUEST']._serialized_end=1384
  _globals['_GETDEFAULTWORKSPACEVALUESRESPONSE']._serialized_start=1386
  _globals['_GETDEFAULTWORKSPACEVALUESRESPONSE']._serialized_end=1508
  _globals['_MARKBUILDASCOPIEDREQUEST']._serialized_start=1510
  _globals['_MARKBUILDASCOPIEDREQUEST']._serialized_end=1576
  _globals['_MARKBUILDASCOPIEDRESPONSE']._serialized_start=1578
  _globals['_MARKBUILDASCOPIEDRESPONSE']._serialized_end=1605
  _globals['_COPYBUILDREQUEST']._serialized_start=1607
  _globals['_COPYBUILDREQUEST']._serialized_end=1665
  _globals['_COPYBUILDRESPONSE']._serialized_start=1667
  _globals['_COPYBUILDRESPONSE']._serialized_end=1686
  _globals['_WORKSPACEMANAGEMENTSERVICE']._serialized_start=1689
  _globals['_WORKSPACEMANAGEMENTSERVICE']._serialized_end=3523
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/ecosystem/v0/auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cqwak/ecosystem/v0/auth.proto\x12\x11qwak.ecosystem.v0\x1a\x1fgoogle/protobuf/timestamp.proto\"U\n\x14OAuthTokenCredential\x12\r\n\x05token\x18\x01 \x01(\t\x12.\n\nexpired_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\xb7\x01\n\x1c\x63om.qwak.ai.common.ecosystemP\x01Z\x94\x01github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/v0;ecosystem_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.ecosystem.v0.auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.qwak.ai.common.ecosystemP\001Z\224\001github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/v0;ecosystem_v0'
  _globals['_OAUTHTOKENCREDENTIAL']._serialized_start=84
  _globals['_OAUTHTOKENCREDENTIAL']._serialized_end=169
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/hosting/azure/auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.creds import secret_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_creds_dot_secret__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0.external.databricks import auth_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_external_dot_databricks_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEqwak/administration/runtime_configuration/v0/hosting/azure/auth.proto\x12:qwak.administration.runtime_configuration.v0.hosting.azure\x1a?qwak/administration/runtime_configuration/v0/creds/secret.proto\x1aKqwak/administration/runtime_configuration/v0/external/databricks/auth.proto\"\xa1\x01\n\x13\x41zureAuthentication\x12\x81\x01\n\x15\x61zure_databricks_auth\x18\x01 \x01(\x0b\x32`.qwak.administration.runtime_configuration.v0.hosting.azure.AzureDatabricksServiceAuthenticationH\x00\x42\x06\n\x04type\"\xfc\x01\n$AzureDatabricksServiceAuthentication\x12\x61\n\x07\x64\x62_auth\x18\x01 \x01(\x0b\x32P.qwak.administration.runtime_configuration.v0.external.databricks.DatabricksAuth\x12q\n\x17\x61zure_blob_storage_auth\x18\x02 \x01(\x0b\x32P.qwak.administration.runtime_configuration.v0.hosting.azure.AzureBlobStorageAuth\"\xf1\x01\n\x14\x41zureBlobStorageAuth\x12^\n\tsas_token\x18\x01 \x01(\x0b\x32I.qwak.administration.runtime_configuration.v0.hosting.azure.AzureSASTokenH\x00\x12l\n\x10managed_identity\x18\x02 \x01(\x0b\x32P.qwak.administration.runtime_configuration.v0.hosting.azure.AzureManagedIdentityH\x00\x42\x0b\n\tauth_type\"v\n\rAzureSASToken\x12Y\n\x06secret\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.creds.secret.SecretKeyRefH\x00\x42\n\n\x08location\"\xb9\x01\n\x14\x41zureManagedIdentity\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x85\x01\n\x15\x66\x65\x64\x65rated_credentials\x18\x02 \x01(\x0b\x32\x64.qwak.administration.runtime_configuration.v0.hosting.azure.KubernetesFederatedCredentialsDescriptorH\x00\x42\x06\n\x04type\"H\n(KubernetesFederatedCredentialsDescriptor\x12\x1c\n\x14service_account_name\x18\x01 \x01(\tB\xdd\x01\n3com.jfrog.ml.runtime_configuration.v0.hosting.azureP\x01Z\xa3\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/hosting/azure;hosting_azureb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.runtime_configuration.v0.hosting.azure.auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n3com.jfrog.ml.runtime_configuration.v0.hosting.azureP\001Z\243\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/hosting/azure;hosting_azure'
  _globals['_AZUREAUTHENTICATION']._serialized_start=276
  _globals['_AZUREAUTHENTICATION']._serialized_end=437
  _globals['_AZUREDATABRICKSSERVICEAUTHENTICATION']._serialized_start=440
  _globals['_AZUREDATABRICKSSERVICEAUTHENTICATION']._serialized_end=692
  _globals['_AZUREBLOBSTORAGEAUTH']._serialized_start=695
  _globals['_AZUREBLOBSTORAGEAUTH']._serialized_end=936
  _globals['_AZURESASTOKEN']._serialized_start=938
  _globals['_AZURESASTOKEN']._serialized_end=1056
  _globals['_AZUREMANAGEDIDENTITY']._serialized_start=1059
  _globals['_AZUREMANAGEDIDENTITY']._serialized_end=1244
  _globals['_KUBERNETESFEDERATEDCREDENTIALSDESCRIPTOR']._serialized_start=1246
  _globals['_KUBERNETESFEDERATEDCREDENTIALSDESCRIPTOR']._serialized_end=1318
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/integration/open_a_i_integration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/integration/open_a_i_integration.proto\x12\x1bqwak.integration.management\"\x8f\x01\n\x11OpenAIIntegration\x12r\n\'openai_api_key_system_secret_descriptor\x18\x01 \x01(\x0b\x32?.qwak.integration.management.OpenAIApiKeySystemSecretDescriptorH\x00\x42\x06\n\x04\x61uth\"z\n\x15OpenAIIntegrationSpec\x12Y\n\x1aopenai_api_key_auth_config\x18\x01 \x01(\x0b\x32\x33.qwak.integration.management.OpenAIApiKeyAuthConfigH\x00\x42\x06\n\x04\x61uth\")\n\x16OpenAIApiKeyAuthConfig\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\"U\n\"OpenAIApiKeySystemSecretDescriptor\x12\x13\n\x0bsecret_name\x18\x01 \x01(\t\x12\x1a\n\x12\x61pi_key_secret_key\x18\x02 \x01(\t\"y\n\x14OpenAIValidationSpec\x12Y\n\x1aopenai_api_key_auth_config\x18\x01 \x01(\x0b\x32\x33.qwak.integration.management.OpenAIApiKeyAuthConfigH\x00\x42\x06\n\x04\x61uth\"\x1a\n\x18OpenAIIntegrationOptionsBH\n&com.qwak.ai.management.integration.apiP\x01Z\x1cqwak/integration;integrationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.integration.open_a_i_integration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.integration.apiP\001Z\034qwak/integration;integration'
  _globals['_OPENAIINTEGRATION']._serialized_start=77
  _globals['_OPENAIINTEGRATION']._serialized_end=220
  _globals['_OPENAIINTEGRATIONSPEC']._serialized_start=222
  _globals['_OPENAIINTEGRATIONSPEC']._serialized_end=344
  _globals['_OPENAIAPIKEYAUTHCONFIG']._serialized_start=346
  _globals['_OPENAIAPIKEYAUTHCONFIG']._serialized_end=387
  _globals['_OPENAIAPIKEYSYSTEMSECRETDESCRIPTOR']._serialized_start=389
  _globals['_OPENAIAPIKEYSYSTEMSECRETDESCRIPTOR']._serialized_end=474
  _globals['_OPENAIVALIDATIONSPEC']._serialized_start=476
  _globals['_OPENAIVALIDATIONSPEC']._serialized_end=597
  _globals['_OPENAIINTEGRATIONOPTIONS']._serialized_start=599
  _globals['_OPENAIINTEGRATIONOPTIONS']._serialized_end=625
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.creds.secret_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ClusterNetworkConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    @property
    def gateway(self) -> global___GatewayConfiguration: ...
    url: builtins.str
    def __init__(
        self,
        *,
        gateway: global___GatewayConfiguration | None = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gateway", b"gateway"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gateway", b"gateway", "url", b"url"]) -> None: ...

global___ClusterNetworkConfiguration = ClusterNetworkConfiguration

class EnvironmentNetworkConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_FIELD_NUMBER: builtins.int
    SERVICES_URL_FIELD_NUMBER: builtins.int
    MODELS_URL_FIELD_NUMBER: builtins.int
    @property
    def gateway(self) -> global___GatewayConfiguration: ...
    services_url: builtins.str
    models_url: builtins.str
    def __init__(
        self,
        *,
        gateway: global___GatewayConfiguration | None = ...,
        services_url: builtins.str = ...,
        models_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gateway", b"gateway"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gateway", b"gateway", "models_url", b"models_url", "services_url", b"services_url"]) -> None: ...

global___EnvironmentNetworkConfiguration = EnvironmentNetworkConfiguration

class GatewayConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISTIO_FIELD_NUMBER: builtins.int
    @property
    def istio(self) -> global___IstioGatewayConfiguration: ...
    def __init__(
        self,
        *,
        istio: global___IstioGatewayConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["istio", b"istio", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["istio", b"istio", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["istio"] | None: ...

global___GatewayConfiguration = GatewayConfiguration

class IstioGatewayConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_FIELD_NUMBER: builtins.int
    @property
    def certificate(self) -> qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef: ...
    def __init__(
        self,
        *,
        certificate: qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["certificate", b"certificate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate"]) -> None: ...

global___IstioGatewayConfiguration = IstioGatewayConfiguration

class Certificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_FIELD_NUMBER: builtins.int
    @property
    def secret(self) -> qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef: ...
    def __init__(
        self,
        *,
        secret: qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["location", b"location", "secret", b"secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "secret", b"secret"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["location", b"location"]) -> typing_extensions.Literal["secret"] | None: ...

global___Certificate = Certificate



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.builds import builds_orchestrator_service_pb2 as qwak_dot_builds_dot_builds__orchestrator__service__pb2


class BuildsOrchestratorServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BuildModel = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/BuildModel',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.BuildModelRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.BuildModelResponse.FromString,
                )
        self.CancelBuildModel = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/CancelBuildModel',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CancelBuildModelRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CancelBuildModelResponse.FromString,
                )
        self.CreateUploadURL = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/CreateUploadURL',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateUploadURLRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateUploadURLResponse.FromString,
                )
        self.GetBuildVersioningUploadURL = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningUploadURL',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadURLRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadURLResponse.FromString,
                )
        self.GetBuildVersioningUploadUrls = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningUploadUrls',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadUrlsRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadUrlsResponse.FromString,
                )
        self.GetBuildVersioningDownloadURL = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningDownloadURL',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadURLRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadURLResponse.FromString,
                )
        self.GetBuildVersioningDownloadUrls = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningDownloadUrls',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadUrLsRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadUrlsResponse.FromString,
                )
        self.ListBuildVersioningTags = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/ListBuildVersioningTags',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildVersioningTagsRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildVersioningTagsResponse.FromString,
                )
        self.CreateDataTable = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/CreateDataTable',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateDataTableRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateDataTableResponse.FromString,
                )
        self.GetBaseDockerImageName = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBaseDockerImageName',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBaseDockerImageNameRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBaseDockerImageNameResponse.FromString,
                )
        self.SaveArtifactPath = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/SaveArtifactPath',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.SaveArtifactPathRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.SaveArtifactPathResponse.FromString,
                )
        self.ListBuildArtifacts = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/ListBuildArtifacts',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildArtifactsRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildArtifactsResponse.FromString,
                )
        self.DetachBuildsFromModelVersions = channel.unary_unary(
                '/qwak.builds.orchestrator.BuildsOrchestratorService/DetachBuildsFromModelVersions',
                request_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.DetachBuildsFromModelVersionsRequest.SerializeToString,
                response_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.DetachBuildsFromModelVersionsResponse.FromString,
                )


class BuildsOrchestratorServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def BuildModel(self, request, context):
        """Build a serving model image
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelBuildModel(self, request, context):
        """Cancel an ongoing build
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUploadURL(self, request, context):
        """Request the service for a path ready for upload in purpose of uploading local model code available to the service
        and the download link corresponding
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildVersioningUploadURL(self, request, context):
        """Request the service for a path ready for upload in purpose of uploading local model code or data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildVersioningUploadUrls(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildVersioningDownloadURL(self, request, context):
        """Request the service for a path ready for download the artifact
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildVersioningDownloadUrls(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBuildVersioningTags(self, request, context):
        """Request the service for a list of paths ready for download the artifact
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataTable(self, request, context):
        """Create data table for build.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBaseDockerImageName(self, request, context):
        """Get the base docker image name for the given Base Image Docker Type
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SaveArtifactPath(self, request, context):
        """Save the artifact path to the database
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBuildArtifacts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetachBuildsFromModelVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BuildsOrchestratorServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BuildModel': grpc.unary_unary_rpc_method_handler(
                    servicer.BuildModel,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.BuildModelRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.BuildModelResponse.SerializeToString,
            ),
            'CancelBuildModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelBuildModel,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CancelBuildModelRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CancelBuildModelResponse.SerializeToString,
            ),
            'CreateUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUploadURL,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateUploadURLRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateUploadURLResponse.SerializeToString,
            ),
            'GetBuildVersioningUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildVersioningUploadURL,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadURLRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadURLResponse.SerializeToString,
            ),
            'GetBuildVersioningUploadUrls': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildVersioningUploadUrls,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadUrlsRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadUrlsResponse.SerializeToString,
            ),
            'GetBuildVersioningDownloadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildVersioningDownloadURL,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadURLRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadURLResponse.SerializeToString,
            ),
            'GetBuildVersioningDownloadUrls': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildVersioningDownloadUrls,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadUrLsRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadUrlsResponse.SerializeToString,
            ),
            'ListBuildVersioningTags': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBuildVersioningTags,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildVersioningTagsRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildVersioningTagsResponse.SerializeToString,
            ),
            'CreateDataTable': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataTable,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateDataTableRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateDataTableResponse.SerializeToString,
            ),
            'GetBaseDockerImageName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBaseDockerImageName,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBaseDockerImageNameRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBaseDockerImageNameResponse.SerializeToString,
            ),
            'SaveArtifactPath': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveArtifactPath,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.SaveArtifactPathRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.SaveArtifactPathResponse.SerializeToString,
            ),
            'ListBuildArtifacts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBuildArtifacts,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildArtifactsRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildArtifactsResponse.SerializeToString,
            ),
            'DetachBuildsFromModelVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.DetachBuildsFromModelVersions,
                    request_deserializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.DetachBuildsFromModelVersionsRequest.FromString,
                    response_serializer=qwak_dot_builds_dot_builds__orchestrator__service__pb2.DetachBuildsFromModelVersionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.builds.orchestrator.BuildsOrchestratorService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BuildsOrchestratorService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def BuildModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/BuildModel',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.BuildModelRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.BuildModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelBuildModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/CancelBuildModel',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.CancelBuildModelRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.CancelBuildModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/CreateUploadURL',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateUploadURLRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildVersioningUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningUploadURL',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadURLRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildVersioningUploadUrls(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningUploadUrls',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadUrlsRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningUploadUrlsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildVersioningDownloadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningDownloadURL',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadURLRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildVersioningDownloadUrls(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBuildVersioningDownloadUrls',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadUrLsRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBuildVersioningDownloadUrlsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBuildVersioningTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/ListBuildVersioningTags',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildVersioningTagsRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildVersioningTagsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/CreateDataTable',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateDataTableRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.CreateDataTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBaseDockerImageName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/GetBaseDockerImageName',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBaseDockerImageNameRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.GetBaseDockerImageNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SaveArtifactPath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/SaveArtifactPath',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.SaveArtifactPathRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.SaveArtifactPathResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBuildArtifacts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/ListBuildArtifacts',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildArtifactsRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.ListBuildArtifactsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DetachBuildsFromModelVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.builds.orchestrator.BuildsOrchestratorService/DetachBuildsFromModelVersions',
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.DetachBuildsFromModelVersionsRequest.SerializeToString,
            qwak_dot_builds_dot_builds__orchestrator__service__pb2.DetachBuildsFromModelVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.creds.auth_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class KafkaConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOTSTRAP_SERVERS_FIELD_NUMBER: builtins.int
    BASIC_AUTH_FIELD_NUMBER: builtins.int
    SECURITY_PROTOCOL_FIELD_NUMBER: builtins.int
    bootstrap_servers: builtins.str
    @property
    def basic_auth(self) -> qwak.administration.runtime_configuration.v0.creds.auth_pb2.BasicAuth: ...
    @property
    def security_protocol(self) -> global___KafkaSecurityProtocolConfig: ...
    def __init__(
        self,
        *,
        bootstrap_servers: builtins.str = ...,
        basic_auth: qwak.administration.runtime_configuration.v0.creds.auth_pb2.BasicAuth | None = ...,
        security_protocol: global___KafkaSecurityProtocolConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "basic_auth", b"basic_auth", "security_protocol", b"security_protocol"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "basic_auth", b"basic_auth", "bootstrap_servers", b"bootstrap_servers", "security_protocol", b"security_protocol"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["basic_auth", "security_protocol"] | None: ...

global___KafkaConfiguration = KafkaConfiguration

class KafkaSecurityProtocolConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAIN_TEXT_FIELD_NUMBER: builtins.int
    SSL_FIELD_NUMBER: builtins.int
    @property
    def plain_text(self) -> global___KafkaPlainTextSecurityProtocolConfig: ...
    @property
    def ssl(self) -> global___KafkaSslSecurityProtocolConfig: ...
    def __init__(
        self,
        *,
        plain_text: global___KafkaPlainTextSecurityProtocolConfig | None = ...,
        ssl: global___KafkaSslSecurityProtocolConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["plain_text", b"plain_text", "security_protocol", b"security_protocol", "ssl", b"ssl"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["plain_text", b"plain_text", "security_protocol", b"security_protocol", "ssl", b"ssl"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["security_protocol", b"security_protocol"]) -> typing_extensions.Literal["plain_text", "ssl"] | None: ...

global___KafkaSecurityProtocolConfig = KafkaSecurityProtocolConfig

class KafkaPlainTextSecurityProtocolConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___KafkaPlainTextSecurityProtocolConfig = KafkaPlainTextSecurityProtocolConfig

class KafkaSslSecurityProtocolConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___KafkaSslSecurityProtocolConfig = KafkaSslSecurityProtocolConfig



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/vectors/v1/filters.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dqwak/vectors/v1/filters.proto\x12\x1cqwak.vector.store.serving.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbb\x01\n\rAtomicLiteral\x12\x18\n\x0estring_literal\x18\x01 \x01(\tH\x00\x12\x15\n\x0bint_literal\x18\x02 \x01(\x03H\x00\x12\x16\n\x0c\x62ool_literal\x18\x03 \x01(\x08H\x00\x12\x18\n\x0e\x64ouble_literal\x18\x04 \x01(\x01H\x00\x12\x37\n\x11timestamp_literal\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x42\x0e\n\x0cliteral_type\"\xf9\x04\n\x06\x46ilter\x12.\n\x02or\x18\x01 \x01(\x0b\x32 .qwak.vector.store.serving.v1.OrH\x00\x12\x30\n\x03\x61nd\x18\x02 \x01(\x0b\x32!.qwak.vector.store.serving.v1.AndH\x00\x12\x31\n\x02\x65q\x18\x03 \x01(\x0b\x32#.qwak.vector.store.serving.v1.EqualH\x00\x12\x34\n\x02ne\x18\x04 \x01(\x0b\x32&.qwak.vector.store.serving.v1.NotEqualH\x00\x12\x37\n\x02gt\x18\x05 \x01(\x0b\x32).qwak.vector.store.serving.v1.GreaterThanH\x00\x12=\n\x03gte\x18\x06 \x01(\x0b\x32..qwak.vector.store.serving.v1.GreaterThanEqualH\x00\x12\x34\n\x02lt\x18\x07 \x01(\x0b\x32&.qwak.vector.store.serving.v1.LessThanH\x00\x12:\n\x03lte\x18\x08 \x01(\x0b\x32+.qwak.vector.store.serving.v1.LessThanEqualH\x00\x12\x32\n\x04like\x18\t \x01(\x0b\x32\".qwak.vector.store.serving.v1.LikeH\x00\x12\x37\n\x07is_null\x18\n \x01(\x0b\x32$.qwak.vector.store.serving.v1.IsNullH\x00\x12>\n\x0bis_not_null\x18\x0b \x01(\x0b\x32\'.qwak.vector.store.serving.v1.IsNotNullH\x00\x42\r\n\x0b\x66ilter_case\"m\n\x02Or\x12\x32\n\x04left\x18\x01 \x01(\x0b\x32$.qwak.vector.store.serving.v1.Filter\x12\x33\n\x05right\x18\x02 \x01(\x0b\x32$.qwak.vector.store.serving.v1.Filter\"n\n\x03\x41nd\x12\x32\n\x04left\x18\x01 \x01(\x0b\x32$.qwak.vector.store.serving.v1.Filter\x12\x33\n\x05right\x18\x02 \x01(\x0b\x32$.qwak.vector.store.serving.v1.Filter\"U\n\x05\x45qual\x12\x10\n\x08property\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qwak.vector.store.serving.v1.AtomicLiteral\"X\n\x08NotEqual\x12\x10\n\x08property\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qwak.vector.store.serving.v1.AtomicLiteral\"[\n\x0bGreaterThan\x12\x10\n\x08property\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qwak.vector.store.serving.v1.AtomicLiteral\"`\n\x10GreaterThanEqual\x12\x10\n\x08property\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qwak.vector.store.serving.v1.AtomicLiteral\"X\n\x08LessThan\x12\x10\n\x08property\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qwak.vector.store.serving.v1.AtomicLiteral\"]\n\rLessThanEqual\x12\x10\n\x08property\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qwak.vector.store.serving.v1.AtomicLiteral\")\n\x04Like\x12\x10\n\x08property\x18\x01 \x01(\t\x12\x0f\n\x07pattern\x18\x02 \x01(\t\"\x1a\n\x06IsNull\x12\x10\n\x08property\x18\x01 \x01(\t\"\x1d\n\tIsNotNull\x12\x10\n\x08property\x18\x01 \x01(\tB\x1e\n\x1a\x63om.qwak.ai.vectors.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.vectors.v1.filters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.qwak.ai.vectors.api.v1P\001'
  _globals['_ATOMICLITERAL']._serialized_start=97
  _globals['_ATOMICLITERAL']._serialized_end=284
  _globals['_FILTER']._serialized_start=287
  _globals['_FILTER']._serialized_end=920
  _globals['_OR']._serialized_start=922
  _globals['_OR']._serialized_end=1031
  _globals['_AND']._serialized_start=1033
  _globals['_AND']._serialized_end=1143
  _globals['_EQUAL']._serialized_start=1145
  _globals['_EQUAL']._serialized_end=1230
  _globals['_NOTEQUAL']._serialized_start=1232
  _globals['_NOTEQUAL']._serialized_end=1320
  _globals['_GREATERTHAN']._serialized_start=1322
  _globals['_GREATERTHAN']._serialized_end=1413
  _globals['_GREATERTHANEQUAL']._serialized_start=1415
  _globals['_GREATERTHANEQUAL']._serialized_end=1511
  _globals['_LESSTHAN']._serialized_start=1513
  _globals['_LESSTHAN']._serialized_end=1601
  _globals['_LESSTHANEQUAL']._serialized_start=1603
  _globals['_LESSTHANEQUAL']._serialized_end=1696
  _globals['_LIKE']._serialized_start=1698
  _globals['_LIKE']._serialized_end=1739
  _globals['_ISNULL']._serialized_start=1741
  _globals['_ISNULL']._serialized_end=1767
  _globals['_ISNOTNULL']._serialized_start=1769
  _globals['_ISNOTNULL']._serialized_end=1798
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/admiral/user_application_instance/v0/user_application_instance_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.admiral.user_application_instance.v0 import user_application_instance_pb2 as qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQqwak/admiral/user_application_instance/v0/user_application_instance_service.proto\x12!qwak.admiral.user_app_instance.v0\x1aIqwak/admiral/user_application_instance/v0/user_application_instance.proto\"p\n$CreateUserApplicationInstanceRequest\x12H\n\x0e\x63reate_options\x18\x01 \x01(\x0b\x32\x30.qwak.admiral.user_app_instance.v0.CreateOptions\"\'\n%CreateUserApplicationInstanceResponse\"x\n(UpdateUserApplicationInstanceSpecRequest\x12L\n\x0eupdate_options\x18\x01 \x01(\x0b\x32\x34.qwak.admiral.user_app_instance.v0.UpdateSpecOptions\"+\n)UpdateUserApplicationInstanceSpecResponse\"f\n!GetUserApplicationInstanceRequest\x12\x41\n\nidentifier\x18\x01 \x01(\x0b\x32-.qwak.admiral.user_app_instance.v0.Identifier\"i\n\"GetUserApplicationInstanceResponse\x12\x43\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32..qwak.admiral.user_app_instance.v0.Description\"i\n$DeleteUserApplicationInstanceRequest\x12\x41\n\nidentifier\x18\x01 \x01(\x0b\x32-.qwak.admiral.user_app_instance.v0.Identifier\"\'\n%DeleteUserApplicationInstanceResponse2\xf7\x05\n\x1eUserApplicationInstanceService\x12\xb2\x01\n\x1d\x43reateUserApplicationInstance\x12G.qwak.admiral.user_app_instance.v0.CreateUserApplicationInstanceRequest\x1aH.qwak.admiral.user_app_instance.v0.CreateUserApplicationInstanceResponse\x12\xbe\x01\n!UpdateUserApplicationInstanceSpec\x12K.qwak.admiral.user_app_instance.v0.UpdateUserApplicationInstanceSpecRequest\x1aL.qwak.admiral.user_app_instance.v0.UpdateUserApplicationInstanceSpecResponse\x12\xa9\x01\n\x1aGetUserApplicationInstance\x12\x44.qwak.admiral.user_app_instance.v0.GetUserApplicationInstanceRequest\x1a\x45.qwak.admiral.user_app_instance.v0.GetUserApplicationInstanceResponse\x12\xb2\x01\n\x1d\x44\x65leteUserApplicationInstance\x12G.qwak.admiral.user_app_instance.v0.DeleteUserApplicationInstanceRequest\x1aH.qwak.admiral.user_app_instance.v0.DeleteUserApplicationInstanceResponseB\xbe\x01\n(com.qwak.ai.admiral.user_app_instance.v0P\x01Z\x8f\x01github.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/user_application_instance/v0;user_application_instance_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.qwak.ai.admiral.user_app_instance.v0P\001Z\217\001github.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/user_application_instance/v0;user_application_instance_v0'
  _globals['_CREATEUSERAPPLICATIONINSTANCEREQUEST']._serialized_start=195
  _globals['_CREATEUSERAPPLICATIONINSTANCEREQUEST']._serialized_end=307
  _globals['_CREATEUSERAPPLICATIONINSTANCERESPONSE']._serialized_start=309
  _globals['_CREATEUSERAPPLICATIONINSTANCERESPONSE']._serialized_end=348
  _globals['_UPDATEUSERAPPLICATIONINSTANCESPECREQUEST']._serialized_start=350
  _globals['_UPDATEUSERAPPLICATIONINSTANCESPECREQUEST']._serialized_end=470
  _globals['_UPDATEUSERAPPLICATIONINSTANCESPECRESPONSE']._serialized_start=472
  _globals['_UPDATEUSERAPPLICATIONINSTANCESPECRESPONSE']._serialized_end=515
  _globals['_GETUSERAPPLICATIONINSTANCEREQUEST']._serialized_start=517
  _globals['_GETUSERAPPLICATIONINSTANCEREQUEST']._serialized_end=619
  _globals['_GETUSERAPPLICATIONINSTANCERESPONSE']._serialized_start=621
  _globals['_GETUSERAPPLICATIONINSTANCERESPONSE']._serialized_end=726
  _globals['_DELETEUSERAPPLICATIONINSTANCEREQUEST']._serialized_start=728
  _globals['_DELETEUSERAPPLICATIONINSTANCEREQUEST']._serialized_end=833
  _globals['_DELETEUSERAPPLICATIONINSTANCERESPONSE']._serialized_start=835
  _globals['_DELETEUSERAPPLICATIONINSTANCERESPONSE']._serialized_end=874
  _globals['_USERAPPLICATIONINSTANCESERVICE']._serialized_start=877
  _globals['_USERAPPLICATIONINSTANCESERVICE']._serialized_end=1636
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class LogLine(google.protobuf.message.Message):
    """Represent a log line"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TEXT_FIELD_NUMBER: builtins.int
    SOURCE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    INGESTED_ISO_TIMESTAMP_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Text of the log"""
    source_instance_id: builtins.str
    """Id of the instance which output the line"""
    ingested_iso_timestamp: builtins.str
    """The timestamp the log was ingested"""
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Metadata for the log ling"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        source_instance_id: builtins.str = ...,
        ingested_iso_timestamp: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ingested_iso_timestamp", b"ingested_iso_timestamp", "metadata", b"metadata", "source_instance_id", b"source_instance_id", "text", b"text"]) -> None: ...

global___LogLine = LogLine



from _qwak_proto.qwak.admiral.user_application_instance.v0.user_application_instance_pb2 import (
    Description,
    Identifier,
    Metadata,
    SpecDescription,
)
from _qwak_proto.qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2 import (
    CreateUserApplicationInstanceRequest,
    CreateUserApplicationInstanceResponse,
    DeleteUserApplicationInstanceRequest,
    DeleteUserApplicationInstanceResponse,
    GetUserApplicationInstanceRequest,
    GetUserApplicationInstanceResponse,
    UpdateUserApplicationInstanceSpecRequest,
    UpdateUserApplicationInstanceSpecResponse,
)
from _qwak_proto.qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2_grpc import (
    UserApplicationInstanceServiceServicer,
)
from qwak_services_mock.mocks.utils.exception_handlers import raise_internal_grpc_error


class UserApplicationInstanceServiceApiMock(UserApplicationInstanceServiceServicer):
    def __init__(self):
        self.revisions = {}
        super(UserApplicationInstanceServiceApiMock, self).__init__()

    @staticmethod
    def _make_key_from_identifier(identifier: Identifier):
        return (
            identifier.name
            + "|"
            + str(identifier.type)
            + "|"
            + identifier.account_id
            + "|"
            + identifier.environment_id
        )

    @staticmethod
    def _get_identifier_from_key(key: str) -> Identifier:
        splitted_key = key.split("|")
        return Identifier(
            name=splitted_key[0],
            type=int(splitted_key[1]),
            account_id=splitted_key[2],
            environment_id=splitted_key[3],
        )

    def CreateUserApplicationInstance(
        self, request: CreateUserApplicationInstanceRequest, context
    ):
        try:
            key = self._make_key_from_identifier(request.create_options.identifier)
            spec = self.revisions.get(key)
            if spec is not None:
                raise Exception("User application already exists")
            self.revisions[key] = request.create_options.spec
            return CreateUserApplicationInstanceResponse()
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def UpdateUserApplicationInstanceSpec(
        self, request: UpdateUserApplicationInstanceSpecRequest, context
    ):
        try:
            key = self._make_key_from_identifier(request.update_options.identifier)
            revision = self.revisions.get(key)
            if revision is None:
                raise Exception("Get Update request but no revision was found")
            self.revisions[key] = request.update_options.spec
            return UpdateUserApplicationInstanceSpecResponse()
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def GetUserApplicationInstance(
        self, request: GetUserApplicationInstanceRequest, context
    ):
        try:
            key = self._make_key_from_identifier(request.identifier)
            spec = self.revisions.get(key)
            if spec is None:
                return GetUserApplicationInstanceResponse()
            description = Description(
                metadata=Metadata(
                    identifier=self._get_identifier_from_key(key=key),
                ),
                spec_description=(SpecDescription(spec=spec)),
            )
            return GetUserApplicationInstanceResponse(description=description)
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def DeleteUserApplicationInstance(
        self, request: DeleteUserApplicationInstanceRequest, context
    ):
        try:
            key = self._make_key_from_identifier(request.identifier)
            spec = self.revisions[key]
            if spec is None:
                raise Exception(f"Could not find revision by the identifier key: {key}")
            self.revisions[key] = None
            return DeleteUserApplicationInstanceResponse()
        except Exception as e:
            raise_internal_grpc_error(context, e)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.self_service.user.v1 import user_service_pb2 as qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2


class UserServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GenerateApiKey = channel.unary_unary(
                '/qwak.self_service.user.v1.UserService/GenerateApiKey',
                request_serializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.GenerateApiKeyRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.GenerateApiKeyResponse.FromString,
                )
        self.RevokeApiKey = channel.unary_unary(
                '/qwak.self_service.user.v1.UserService/RevokeApiKey',
                request_serializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.RevokeApiKeyRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.RevokeApiKeyResponse.FromString,
                )
        self.ListApiKeyDetails = channel.unary_unary(
                '/qwak.self_service.user.v1.UserService/ListApiKeyDetails',
                request_serializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.ListApiKeyDetailsRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.ListApiKeyDetailsResponse.FromString,
                )
        self.GetUserProfile = channel.unary_unary(
                '/qwak.self_service.user.v1.UserService/GetUserProfile',
                request_serializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.GetUserProfileRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.GetUserProfileResponse.FromString,
                )
        self.UpdateUserProfile = channel.unary_unary(
                '/qwak.self_service.user.v1.UserService/UpdateUserProfile',
                request_serializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.UpdateUserProfileRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.UpdateUserProfileResponse.FromString,
                )


class UserServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GenerateApiKey(self, request, context):
        """Invoke password reset process for a given user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeApiKey(self, request, context):
        """Revoke API key for a given user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListApiKeyDetails(self, request, context):
        """List API key details per environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserProfile(self, request, context):
        """Get user profile
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserProfile(self, request, context):
        """Update user profile
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GenerateApiKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateApiKey,
                    request_deserializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.GenerateApiKeyRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.GenerateApiKeyResponse.SerializeToString,
            ),
            'RevokeApiKey': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeApiKey,
                    request_deserializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.RevokeApiKeyRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.RevokeApiKeyResponse.SerializeToString,
            ),
            'ListApiKeyDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.ListApiKeyDetails,
                    request_deserializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.ListApiKeyDetailsRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.ListApiKeyDetailsResponse.SerializeToString,
            ),
            'GetUserProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserProfile,
                    request_deserializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.GetUserProfileRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.GetUserProfileResponse.SerializeToString,
            ),
            'UpdateUserProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserProfile,
                    request_deserializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.UpdateUserProfileRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.UpdateUserProfileResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.self_service.user.v1.UserService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GenerateApiKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.user.v1.UserService/GenerateApiKey',
            qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.GenerateApiKeyRequest.SerializeToString,
            qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.GenerateApiKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevokeApiKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.user.v1.UserService/RevokeApiKey',
            qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.RevokeApiKeyRequest.SerializeToString,
            qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.RevokeApiKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListApiKeyDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.user.v1.UserService/ListApiKeyDetails',
            qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.ListApiKeyDetailsRequest.SerializeToString,
            qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.ListApiKeyDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.user.v1.UserService/GetUserProfile',
            qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.GetUserProfileRequest.SerializeToString,
            qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.GetUserProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.user.v1.UserService/UpdateUserProfile',
            qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.UpdateUserProfileRequest.SerializeToString,
            qwak_dot_self__service_dot_user_dot_v1_dot_user__service__pb2.UpdateUserProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.admiral.secret.v0 import system_secret_service_pb2 as qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2


class SystemSecretServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetSystemSecret = channel.unary_unary(
                '/qwak.admiral.secret.v0.SystemSecretService/SetSystemSecret',
                request_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.SetSystemSecretRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.SetSystemSecretResponse.FromString,
                )
        self.DeleteSystemSecret = channel.unary_unary(
                '/qwak.admiral.secret.v0.SystemSecretService/DeleteSystemSecret',
                request_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.DeleteSystemSecretRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.DeleteSystemSecretResponse.FromString,
                )
        self.GetSystemSecret = channel.unary_unary(
                '/qwak.admiral.secret.v0.SystemSecretService/GetSystemSecret',
                request_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.GetSystemSecretRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.GetSystemSecretResponse.FromString,
                )


class SystemSecretServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SetSystemSecret(self, request, context):
        """Set a value for a secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSystemSecret(self, request, context):
        """Delete secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSystemSecret(self, request, context):
        """Get secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SystemSecretServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetSystemSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSystemSecret,
                    request_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.SetSystemSecretRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.SetSystemSecretResponse.SerializeToString,
            ),
            'DeleteSystemSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSystemSecret,
                    request_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.DeleteSystemSecretRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.DeleteSystemSecretResponse.SerializeToString,
            ),
            'GetSystemSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSystemSecret,
                    request_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.GetSystemSecretRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.GetSystemSecretResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.admiral.secret.v0.SystemSecretService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SystemSecretService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SetSystemSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.secret.v0.SystemSecretService/SetSystemSecret',
            qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.SetSystemSecretRequest.SerializeToString,
            qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.SetSystemSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSystemSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.secret.v0.SystemSecretService/DeleteSystemSecret',
            qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.DeleteSystemSecretRequest.SerializeToString,
            qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.DeleteSystemSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSystemSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.secret.v0.SystemSecretService/GetSystemSecret',
            qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.GetSystemSecretRequest.SerializeToString,
            qwak_dot_admiral_dot_secret_dot_v0_dot_system__secret__service__pb2.GetSystemSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.ecosystem.jfrog.v0.token_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GenerateTokenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_SPEC_FIELD_NUMBER: builtins.int
    @property
    def token_spec(self) -> qwak.ecosystem.jfrog.v0.token_pb2.JFrogTokenSpec:
        """Token spec"""
    def __init__(
        self,
        *,
        token_spec: qwak.ecosystem.jfrog.v0.token_pb2.JFrogTokenSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token_spec", b"token_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_spec", b"token_spec"]) -> None: ...

global___GenerateTokenRequest = GenerateTokenRequest

class GenerateTokenResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    @property
    def token(self) -> qwak.ecosystem.jfrog.v0.token_pb2.JFrogToken:
        """Generated token"""
    def __init__(
        self,
        *,
        token: qwak.ecosystem.jfrog.v0.token_pb2.JFrogToken | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token", b"token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["token", b"token"]) -> None: ...

global___GenerateTokenResponse = GenerateTokenResponse

class GenerateArtifactoryImagePullTokenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_SPEC_FIELD_NUMBER: builtins.int
    @property
    def token_spec(self) -> qwak.ecosystem.jfrog.v0.token_pb2.ArtifactoryImagePullTokenSpec:
        """Artifactory Image pull token spec"""
    def __init__(
        self,
        *,
        token_spec: qwak.ecosystem.jfrog.v0.token_pb2.ArtifactoryImagePullTokenSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token_spec", b"token_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_spec", b"token_spec"]) -> None: ...

global___GenerateArtifactoryImagePullTokenRequest = GenerateArtifactoryImagePullTokenRequest

class GenerateArtifactoryImagePullTokenResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    @property
    def token(self) -> qwak.ecosystem.jfrog.v0.token_pb2.JFrogToken:
        """Generated token"""
    def __init__(
        self,
        *,
        token: qwak.ecosystem.jfrog.v0.token_pb2.JFrogToken | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token", b"token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["token", b"token"]) -> None: ...

global___GenerateArtifactoryImagePullTokenResponse = GenerateArtifactoryImagePullTokenResponse

class PersistTokenClaimsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEC_FIELD_NUMBER: builtins.int
    @property
    def spec(self) -> qwak.ecosystem.jfrog.v0.token_pb2.PersistTokenClaimsSpec:
        """Persist token claims spec"""
    def __init__(
        self,
        *,
        spec: qwak.ecosystem.jfrog.v0.token_pb2.PersistTokenClaimsSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["spec", b"spec"]) -> None: ...

global___PersistTokenClaimsRequest = PersistTokenClaimsRequest

class PersistTokenClaimsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_ID_FIELD_NUMBER: builtins.int
    token_id: builtins.str
    """The persisted token id.
    Used for later retrieval
    """
    def __init__(
        self,
        *,
        token_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_id", b"token_id"]) -> None: ...

global___PersistTokenClaimsResponse = PersistTokenClaimsResponse

class RevokeTokenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_REVOKE_SPEC_FIELD_NUMBER: builtins.int
    @property
    def token_revoke_spec(self) -> qwak.ecosystem.jfrog.v0.token_pb2.JFrogTokenRevokeSpec:
        """Revoke token spec"""
    def __init__(
        self,
        *,
        token_revoke_spec: qwak.ecosystem.jfrog.v0.token_pb2.JFrogTokenRevokeSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token_revoke_spec", b"token_revoke_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_revoke_spec", b"token_revoke_spec"]) -> None: ...

global___RevokeTokenRequest = RevokeTokenRequest

class RevokeTokenRequestResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RevokeTokenRequestResponse = RevokeTokenRequestResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.service_discovery.service_discovery_location_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetServingUrlRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetServingUrlRequest = GetServingUrlRequest

class GetServingUrlRequestResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCATION_FIELD_NUMBER: builtins.int
    @property
    def location(self) -> qwak.service_discovery.service_discovery_location_pb2.ServiceLocationDescriptor: ...
    def __init__(
        self,
        *,
        location: qwak.service_discovery.service_discovery_location_pb2.ServiceLocationDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["location", b"location"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location"]) -> None: ...

global___GetServingUrlRequestResponse = GetServingUrlRequestResponse



from dataclasses import dataclass
from datetime import datetime
from typing import Union


@dataclass
class Context:
    start_time: Union[str, datetime] = "${qwak_ingestion_start_timestamp}"
    end_time: Union[str, datetime] = "${qwak_ingestion_end_timestamp}"



from .quiet_error import QuietError
from .qwak_exception import QwakException
from .qwak_general_build_exception import QwakGeneralBuildException
from .qwak_grpc_address_exception import QwakGrpcAddressException
from .qwak_http_exception import QwakHTTPException
from .qwak_inference_exception import QwakInferenceException
from .qwak_load_configuration_exception import LoadConfigurationException
from .qwak_load_model_failed_exception import QwakLoadModelFailedException
from .qwak_login_exception import QwakLoginException
from .qwak_mock_http_exception import MockHttpException
from .qwak_model_initialization_exception import QwakModelInitializationException
from .qwak_not_found_exception import QwakNotFoundException
from .qwak_remote_build_failed import QwakRemoteBuildFailedException
from .qwak_suggestion_exception import QwakSuggestionException
